@@ -1,5 +1,6 @@
 import re
 import csv
+import gzip
 import json
 import logging
 import requests
@@ -1162,7 +1163,7 @@ def _build_uniprot_entries():
     uniprot_entrez_reverse = {}
     files = [up_entries_file]
     for file in files:
-        with open(file, 'r') as fh:
+        with gzip.open(file, 'rt', encoding='utf-8') as fh:
             csv_rows = csv.reader(fh, delimiter='\t')
             # Skip the header row
             next(csv_rows)
@@ -1212,7 +1213,7 @@ def _build_uniprot_entries():
 
 def _build_human_mouse_rat():
     hgnc_file = resource_manager.get_create_resource_file('hgnc')
-    with open(hgnc_file, 'r') as fh:
+    with gzip.open(hgnc_file, 'rt', encoding='utf-8') as fh:
         csv_rows = csv.reader(fh, delimiter='\t')
         # Skip the header row
         next(csv_rows)
@@ -1240,7 +1241,7 @@ def _build_human_mouse_rat():
 
 def _build_hgnc_mappings():
     hgnc_file = resource_manager.get_create_resource_file('hgnc')
-    with open(hgnc_file, 'r') as fh:
+    with gzip.open(hgnc_file, 'rt', encoding='utf-8') as fh:
         csv_rows = csv.reader(fh, delimiter='\t')
         # Skip the header row
         next(csv_rows)
@@ -1278,10 +1279,11 @@ def _build_uniprot_sec():
     # to primary accession numbers
     sec_file = resource_manager.get_create_resource_file('upsec')
     uniprot_sec = {}
-    lines = open(sec_file, 'rt').readlines()
-    for i, l in enumerate(lines):
-        if l.startswith('Secondary AC'):
-            entry_lines = lines[i+2:]
+    with gzip.open(sec_file, 'rt', encoding='utf-8') as fh:
+        lines = fh.readlines()
+        for i, l in enumerate(lines):
+            if l.startswith('Secondary AC'):
+                entry_lines = lines[i+2:]
 
     for l in entry_lines:
         sec_id, prim_id = l.split()
@@ -1309,7 +1311,7 @@ def _build_refseq_uniprot():
     refseq_uniprot_file = resource_manager.get_create_resource_file(
                                                 'refseq_uniprot')
     refseq_up = {}
-    with open(refseq_uniprot_file, 'rt') as f:
+    with gzip.open(refseq_uniprot_file, 'rt', encoding='utf-8') as f:
         csvreader = csv.reader(f)
         for refseq_id, up_id in csvreader:
             if refseq_id not in refseq_up:
@@ -1320,21 +1322,26 @@ def _build_refseq_uniprot():
 
 def load_fasta_sequences(seq_file, id_delimiter='|', id_index=1):
     sequences = {}
-    with open(seq_file, 'rt') as f:
-        lines = f.readlines()
-        cur_id = None
-        seq_lines = []
-        for line in lines:
-            if line.startswith('>'):
-                line_id = line[1:].split(id_delimiter)[id_index]
-                if cur_id is not None:
-                    seq = ''.join(seq_lines)
-                    sequences[cur_id] = seq
-                    seq_lines = []
-                cur_id = line_id
-            else:
-                seq_lines.append(line.strip())
-        # Add the last sequence
-        seq = ''.join(seq_lines)
-        sequences[cur_id] = seq
+    if seq_file.endswith('gz'):
+        with gzip.open(seq_file, 'rt', encoding='utf-8') as f:
+            lines = f.readlines()
+    # This is necessary for downstream usage of this function
+    else:
+        with open(seq_file, 'rt', encoding='utf-8') as f:
+            lines = f.readlines()
+    cur_id = None
+    seq_lines = []
+    for line in lines:
+        if line.startswith('>'):
+            line_id = line[1:].split(id_delimiter)[id_index]
+            if cur_id is not None:
+                seq = ''.join(seq_lines)
+                sequences[cur_id] = seq
+                seq_lines = []
+            cur_id = line_id
+        else:
+            seq_lines.append(line.strip())
+    # Add the last sequence
+    seq = ''.join(seq_lines)
+    sequences[cur_id] = seq
     return sequences
